@@ -4,11 +4,11 @@
 
 Interfaces for the Zope 3 based converterannotator package
 
-$Id: interfaces.py 49953 2008-02-06 20:22:05Z cray $
+$Id: interfaces.py 50800 2008-02-21 11:13:08Z cray $
 """
 __author__  = "Ischenko Valera, 2006"
 __license__ = "GPL"
-__version__ = "$Revision: 49953 $"
+__version__ = "$Revision: 50800 $"
  
 from zope.interface import Interface
 from zope.schema import Text, TextLine, Field, Int, Bool
@@ -33,9 +33,11 @@ class IConverterAnnotatorAdd(Interface) :
     pattern_sentences = TextLine(
            title=u"Pattern Sentences",
            description=u"Pattern to split text onto by sentences.",
-           default=u"(?uL)(?:(?<=^)|(?<=\s))([^~=\.?!;]+[\.?!;])(?=\s|$)",
+           default=u"(?uL)^\s*[^\.]+\.|\s+[^\.]+\.",
            required=True)
 
+    # u"(?uL)(?:(?<=^)|(?<=\s))([^~=\.?!;]+[\.?!;])(?=\s|$)",
+
     best_count = Int(
            title=u"Count of sentences in annotation",
            description=u"Count of sentences in annotation",
